@@ -6,6 +6,7 @@
 import asyncio
 
 import pymysql
+from dbutils.persistent_db import PersistentDB
 from dbutils.pooled_db import PooledDB
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
@@ -44,8 +45,8 @@ class MysqlPool(BaseConnectionPool):
             await asyncio.sleep(60)
 
     def sync_create_pool(self):
-        pool = PooledDB(creator=pymysql, mincached=self.conn_info.min_size, maxcached=self.conn_info.max_size,
-                        host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
-                        passwd=self.conn_info.password, db=self.conn_info.db_name, charset="utf8",
-                        autocommit=True)
+        pool = PersistentDB(creator=pymysql, ping=2, closeable=False,
+                            host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
+                            passwd=self.conn_info.password, db=self.conn_info.db_name, charset="utf8",
+                            autocommit=True)
         return pool
